Thread (63 messages) 63 messages, 4 authors, 2020-02-17

Re: [PATCH v3 12/40] mtd: nand: Rename a core structure

From: Miquel Raynal <miquel.raynal@bootlin.com>
Date: 2020-01-16 08:53:21

Hi Boris,

Boris Brezillon [off-list ref] wrote on Sat, 12 Oct
2019 11:35:30 +0200:
On Thu, 19 Sep 2019 21:31:12 +0200
Miquel Raynal [off-list ref] wrote:
quoted
Prepare the migration to a generic ECC engine by renaming the
nand_ecc_req structure into nand_ecc_props. This structure will be the
base of a wider 'nand_ecc' structure.

Signed-off-by: Miquel Raynal <miquel.raynal@bootlin.com>
---
 include/linux/mtd/nand.h    | 8 ++++----
 include/linux/mtd/spinand.h | 2 +-
 2 files changed, 5 insertions(+), 5 deletions(-)
diff --git a/include/linux/mtd/nand.h b/include/linux/mtd/nand.h
index 531c1799bf2c..7072f14239e5 100644
--- a/include/linux/mtd/nand.h
+++ b/include/linux/mtd/nand.h
@@ -128,11 +128,11 @@ struct nand_page_io_req {
 };
 
 /**
  * struct nand_ecc_req - NAND ECC requirements
  * @strength: ECC strength
- * @step_size: ECC step/block size
+ * @step_size: Number of bytes per step
  */
-struct nand_ecc_req {
+struct nand_ecc_props {
 	unsigned int strength;
 	unsigned int step_size;
 };
@@ -191,7 +191,7 @@ struct nand_ops {
 struct nand_device {
 	struct mtd_info mtd;
 	struct nand_memory_organization memorg;
-	struct nand_ecc_req eccreq;
+	struct nand_ecc_props eccreq;  
@@ -128,11 +128,11 @@ struct nand_page_io_req {
 
 /**
- * struct nand_ecc_req - NAND ECC requirements
+ * struct nand_ecc_props - NAND ECC properties
  * @strength: ECC strength
Let's rename this field too: s/eccreq/eccprops/
This is just a transition step, this field is being replaced by a much
wider structure two patches later. The impact of renaming this field is
huge compared to its interest so I'd prefer not to do it.

Miquèl

_______________________________________________
linux-arm-kernel mailing list
linux-arm-kernel@lists.infradead.org
http://lists.infradead.org/mailman/listinfo/linux-arm-kernel
Keyboard shortcuts
hback out one level
jnext message in thread
kprevious message in thread
ldrill in
Escclose help / fold thread tree
?toggle this help